import PocketBase from 'pocketbase'

import { defineMiddleware } from 'astro/middleware'
import { getEnv } from 'libs/Env'

export const onRequest = defineMiddleware(async ({ locals, request }: any, next: () => any) => {
	locals.pb = new PocketBase(getEnv('POCKETBASE_URL','http://localhost:8080'))

	// load the store data from the request cookie string
	locals.pb.authStore.loadFromCookie(request.headers.get('cookie') || '')

	try {
		// get an up-to-date auth store state by verifying and refreshing the loaded auth model (if any)
		// eslint-disable-next-line @typescript-eslint/no-unused-expressions
		locals.pb.authStore.isValid && await locals.pb.collection('users').authRefresh()
	} catch (_) {
		// clear the auth store on failed refresh
		locals.pb.authStore.clear()
	}

	const response = await next()

	// send back the default 'pb_auth' cookie to the client with the latest store state
	response.headers.append('set-cookie', locals.pb.authStore.exportToCookie())

	return response
})
